summaryrefslogtreecommitdiffstats
path: root/net/base/host_port_pair.h
diff options
context:
space:
mode:
authorszym@chromium.org <szym@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-05-07 21:44:56 +0000
committerszym@chromium.org <szym@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-05-07 21:44:56 +0000
commit7054e78fe6a2fcda72b06dc196b5f91cfdc75872 (patch)
tree2efdd9b07a784a17905d737df9b762d88a6cd1c4 /net/base/host_port_pair.h
parentcd46545164adf645d744f3955b256cf89412cdc6 (diff)
downloadchromium_src-7054e78fe6a2fcda72b06dc196b5f91cfdc75872.zip
chromium_src-7054e78fe6a2fcda72b06dc196b5f91cfdc75872.tar.gz
chromium_src-7054e78fe6a2fcda72b06dc196b5f91cfdc75872.tar.bz2
Reimplements net::AddressList without struct addrinfo.
net::AddressList extends std::vector<std::IPEndPoint> by canonical name. (Canonical name is planned to be removed as well.) Removes dependency on sys_addrinfo.h throughout the codebase. Introduces net::SockaddrStorage for convenience. BUG=125696 TEST=green waterfall Review URL: http://codereview.chromium.org/10309002 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@135731 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'net/base/host_port_pair.h')
-rw-r--r--net/base/host_port_pair.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/net/base/host_port_pair.h b/net/base/host_port_pair.h
index 1288a44..df22768 100644
--- a/net/base/host_port_pair.h
+++ b/net/base/host_port_pair.h
@@ -10,11 +10,12 @@
#include "base/basictypes.h"
#include "net/base/net_export.h"
-struct addrinfo;
class GURL;
namespace net {
+class IPEndPoint;
+
class NET_EXPORT HostPortPair {
public:
HostPortPair();
@@ -24,8 +25,8 @@ class NET_EXPORT HostPortPair {
// Creates a HostPortPair for the origin of |url|.
static HostPortPair FromURL(const GURL& url);
- // Creates a HostPortPair from an addrinfo struct.
- static HostPortPair FromAddrInfo(const struct addrinfo* ai);
+ // Creates a HostPortPair from an IPEndPoint.
+ static HostPortPair FromIPEndPoint(const IPEndPoint& ipe);
// Creates a HostPortPair from a string formatted in same manner as
// ToString().